@@ -1425,7 +1425,7 @@ xt::pytensor<float,1> LSDDEM_xtensor::burn_rast_val_to_xy(xt::pytensor<float,1>
   for(size_t i=0; i< X_coord.size(); i++)
   {
     // Convert the coordinates to XY, no snaping if the point is out
-    this->XY_to_rowcol(X_coord[i], Y_coord[i], row, col, false);
+    this->XY_to_rowcol_unchecked(X_coord[i], Y_coord[i], row, col);
     // Assigning no data by default
     float val = -9999;
     // Check if the point is in the raser
@@ -2006,6 +2006,36 @@ void LSDDEM_xtensor::XY_to_rowcol(float X_coord, float Y_coord, int& row, int& c
   // No need to return anything: the row/col are passed as adresses
 }
 
+//####################################################################
+// Converts XY coordinates to their row/col equivalent.
+// Possibility to snap to the closest raster edge if the coordinate 
+// falls outside of the DEM (usefull with approximative coord).
+// Authors: B.G.
+//#####################################################################
+void LSDDEM_xtensor::XY_to_rowcol_unchecked(float X_coord, float Y_coord, int& row, int& col)
+{
+  
+  // ## First I change the referential if my minimum coordinates are <0
+  if(xmin<0)
+    {X_coord = X_coord + -1 * xmin; xmin = 0;}
+  // Checking the coordinate
+  float corrected_X = X_coord - xmin;
+  // std::cout << "X_corr is " << corrected_X << std::endl;
+
+  // Exact same process with the Y coordinate, apart from the conversion which needs to be inverted as Y and row are going in opposite directions
+  if(ymin<0)
+    {Y_coord = Y_coord + -1 * ymin; ymin = 0;}
+  // Correcting the coord
+  float corrected_Y = Y_coord - ymin;
+
+  col = floor(corrected_X/cellsize);
+
+  row = (nrows - 1) - floor(corrected_Y/cellsize);
+
+
+  // No need to return anything: the row/col are passed as adresses
+}
+
 
 
 
