@@ -152,8 +152,8 @@ vector<string> DriverIngestor(int nNumberofArgs,char *argv[])
       path_and_file[1] == "HELP" || path_and_file[1] == "-help"  ||
       path_and_file[1] == "-WTF")
   {
-    cout << "You have chosen to print the help file. " << endl;
-    cout << "You can find this with README in the filename." << endl;
+    cout << "I am going to print a help file. There will be a .csv and a .html version. " << endl;
+    cout << "These files have README in the filename." << endl;
     path_and_file[0] = "./";
     path_and_file[1] = "cry_for_help.txt";
 
@@ -182,7 +182,7 @@ vector<string> DriverIngestor(int nNumberofArgs,char *argv[])
       path_and_file[1] == "-citation" || path_and_file[0] == "-Citation"  ||
       path_and_file[1] == "--citation" || path_and_file[0] == "--Citation" )
   {
-    cout << "You have chosen to print the citation information. " << endl;
+    //cout << "You have chosen to print the citation information. " << endl;
     path_and_file[0] = "./";
     path_and_file[1] = "lsdtt_citation.txt";
 
@@ -203,7 +203,7 @@ vector<string> DriverIngestor(int nNumberofArgs,char *argv[])
       path_and_file[1] == "-version" || path_and_file[0] == "-Version"  ||
       path_and_file[1] == "--version" || path_and_file[0] == "--Version" )
   {
-    cout << "You have chosen to print the version. " << endl;
+    //cout << "You have chosen to print the version. " << endl;
     path_and_file[0] = "./";
     path_and_file[1] = "lsdtt_version.txt";
 
@@ -593,8 +593,7 @@ void LSDParameterParser::print_help(map< string, vector<string> > help_map, stri
   // Open the help file
   ofstream help_ofs;
   string help_fname = write_path+help_prefix+".csv";
-  cout << "Printing the help file to: " << endl;
-  cout << help_fname << endl;
+
   help_ofs.open(help_fname.c_str());
   vector<string> this_string_vec;
 
@@ -628,6 +627,69 @@ void LSDParameterParser::print_help(map< string, vector<string> > help_map, stri
   }
 
   help_ofs.close();
+
+
+  // Now we do the html file
+  ofstream help_ofs_html;
+  string help_fname_html = write_path+help_prefix+".html";
+  help_ofs_html.open(help_fname_html.c_str());
+
+  cout << "Printing the help files to: " << endl;
+  cout << help_fname << endl;
+  cout << help_fname_html << endl;
+
+  help_ofs_html << "<!DOCTYPE html>\n<html>\n<head>\n\t<title>Help information for " << help_prefix << "</title>";
+  help_ofs_html << "<style>table, th, td {\n\tborder: 1px solid black;\n\tborder-collapse: collapse;\n}\n</style>\n</head>\n<body>" << endl << endl;
+
+  help_ofs_html << "<h1>Help information for " << help_prefix << "</h1>" << endl << endl;
+  help_ofs_html << "<p>You are using version " << version << " of this software.</p>" << endl; 
+  help_ofs_html << "<p>If the use of this software results in a publication, please cite <a href=\"" << citation << "\">" << citation << "</a>. In addition please also look at statements printed by the code for citations to specific routines and algorithms.</p>" << endl; 
+
+  help_ofs_html << "<h2>Making the parameter file</h2>" << endl;
+  help_ofs_html << "<p>You call lsdtt command line tools with a parameter file. This file can be made in a text editor. ";
+  help_ofs_html << "The programs read ENVI bil format rasters projected into UTM (the WGS84 version). You must convert and project your DEM before using these tools. "; 
+  help_ofs_html << "You should have a line of your parameter file that reads:.</p>" << endl; 
+  help_ofs_html << "<p>read fname: FILE_PREFIX</p>" << endl; 
+  help_ofs_html << "<p>where FILE_PREFIX is the name of the raster without the .bil extension</p>" << endl;
+  help_ofs_html << "<p>The rest of the parameter file has the format:</p>\n<p>PARAMETER_NAME: VALUE</p><p>That is, there needs to be a colon and a space after the parameter name." << endl;
+  help_ofs_html << "The default parameter value will be used if you don't give the parameter file the name and value of a parameter</p>" << endl << endl;
+
+  // And now for the table. 
+  // First the header
+  help_ofs_html << "<h2>Parameter table</h2>" << endl;
+  help_ofs_html << "<table>\n\t<colgroup>\n\t\t<col span=\"1\" style=\"width: 15%;\">"
+                << "\n\t\t<col span=\"1\" style=\"width: 10%;\">"
+                << "\n\t\t<col span=\"1\" style=\"width: 15%;\">"
+                << "\n\t\t<col span=\"1\" style=\"width: 30%;\">"
+                << "\n\t\t<col span=\"1\" style=\"width: 30%;\">"
+                << "\n\t</colgroup>" << endl;
+  
+  help_ofs_html << "\n\t<tbody>\n\t<tr>\n\t\t<th>param name</th>\n\t\t<th>type</th>\n\t\t<th>default</th>\n\t\t<th>description</th>\n\t\t<th>guidance</th>\n\t</tr>" << endl;
+
+  // And now for the rest of it. 
+  for(int i = 0; i< int(these_keys.size()); i++)
+  {
+    //cout << "The key is: " <<  these_keys[i] << endl;
+    if ( help_map.find( these_keys[i] ) == help_map.end() ) 
+    {
+      help_ofs_html << "\t<tr>\n\t\t<td>" << these_keys[i] << "</td>\n\t\t<td>not available</td>\n\t\t<td>not available</td>\n\t\t<td>not available</td>\n\t\t<td>not available</td>\n\t</tr>" << endl;
+    } 
+    else 
+    {
+      this_string_vec = help_map[ these_keys[i] ];
+
+      help_ofs_html << "\t<tr>\n\t\t<td>" << these_keys[i] << "</td>\n\t\t<td>" << this_string_vec[0] << "</td>\n\t\t<td>" 
+                    << this_string_vec[1] << "</td>\n\t\t<td>" << this_string_vec[2] << "</td>\n\t\t<td>"
+                    << this_string_vec[3] <<"</td>\n\t</tr>" << endl;
+    }
+
+  }
+
+  // and now the end
+  help_ofs_html << "\n\t<tbody>\n\t</table>\n\t</body>\n</html>" << endl;
+
+  help_ofs_html.close();
+
 }
 
 //-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
