@@ -142,9 +142,11 @@ class LSDParameterParser
     /// @brief This processes the help information
     /// @param help_map the map of string vectors containing help information. 
     /// @param the file prefix of the help file
+    /// @param the version the help file refers to 
+    /// @param the appropriate citation for the code
     /// @author SMM
-    /// @date 13/03/2021
-    void print_help(map< string, vector<string> > help_map, string file_prefix);
+    /// @date 21/07/2021 
+    void print_help(map< string, vector<string> > help_map, string file_prefix, string version, string citation);
 
 
     /// @brief This function takes a default map and converts it into the parameters
