@@ -144,25 +144,28 @@ class LSDRasterMaker: public LSDRaster
     /// @brief This fixes a channel, derived from source points data
     ///  onto the model DEM
     /// @param source_points_data an LSDSpatialCSVReader object. It needs lat and long and elevation columns
+    /// @param column_name the name of the elevation column
     /// @author SMM
     /// @date 04/03/2020
-    void impose_channels(LSDSpatialCSVReader& source_points_data);
+    void impose_channels(LSDSpatialCSVReader& source_points_data, string column_name);
 
     /// @brief This fixes a channel, derived from source points data. It also makes sure none of these nodes is 
     ///   adjacent to a nodata pixel
     /// @param source_points_data an LSDSpatialCSVReader object. It needs lat and long and elevation columns
     /// @param slope the slope between the data point and the adjacent pixel
+    /// @param column_name the name of the elevation column
     /// @author SMM
     /// @date 21/11/2020
-    void impose_channels_with_buffer(LSDSpatialCSVReader& source_points_data, float slope);
+    void impose_channels_with_buffer(LSDSpatialCSVReader& source_points_data, float slope, string column_name);
 
     /// @brief This fixes a channel, derived from source points data. It also makes sure none of these nodes is 
     ///   adjacent to a nodata pixel. Same as the above function, but uses XY data instead of lat-long
     /// @param source_points_data an LSDSpatialCSVReader object. It needs XY and elevation columns
     /// @param slope the slope between the data point and the adjacent pixel
+    /// @param column_name the name of the elevation column
     /// @author ELSG
     /// @date 23/02/2021
-    void impose_channels_with_buffer_use_XY(LSDSpatialCSVReader& source_points_data, float slope);
+    void impose_channels_with_buffer_use_XY(LSDSpatialCSVReader& source_points_data, float slope, string column_name);
 
     /// @brief This function adds elevation to the nodata pixels around the edge of a DEM
     ///  It is used to crinkle up the edge of of a raster to ensure drainage 
