@@ -231,7 +231,7 @@ void LSDSpatialCSVReader::load_csv_data(string filename)
 
   // create a stringstream
   stringstream ss(line_from_file);
-  ss.precision(9);
+  ss.precision(14);
 
   while( ss.good() )
   {
@@ -1515,11 +1515,11 @@ void LSDSpatialCSVReader::get_row_and_col_of_a_point(float X_coordinate,float Y_
 
   //cout << "Getting row and col, " << row_point << " " << col_point << endl;
 
-  if(col_point > 0 && col_point < NCols-1)
+  if(col_point >= 0 && col_point <= NCols-1)
   {
     this_col = col_point;
   }
-  if(row_point > 0 && row_point < NRows -1)
+  if(row_point >= 0 && row_point <= NRows -1)
   {
     this_row = row_point;
   }
@@ -1543,11 +1543,11 @@ void LSDSpatialCSVReader::get_row_and_col_of_a_point(double X_coordinate,double
 
   //cout << "Getting row and col, " << row_point << " " << col_point << endl;
 
-  if(col_point > 0 && col_point < NCols-1)
+  if(col_point >= 0 && col_point <= NCols-1)
   {
     this_col = col_point;
   }
-  if(row_point > 0 && row_point < NRows -1)
+  if(row_point >= 0 && row_point <= NRows -1)
   {
     this_row = row_point;
   }
